==> qtjambi-serialbus-debuginfo-macos-6.6.0.jar: sources/QtJambiSerialBus/QModbusTcpConnectionObserver_shell.cpp <==
#include "QModbusTcpConnectionObserver_shell.h"
#include <QtJambi/Cast>

void deleter_QModbusTcpConnectionObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QModbusTcpConnectionObserver")
    QModbusTcpConnectionObserver *_ptr = reinterpret_cast<QModbusTcpConnectionObserver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QModbusTcpConnectionObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QModbusTcpConnectionObserver_shell) ); }

jmethodID QModbusTcpConnectionObserver_shell::__shell_javaMethod(int pos) const { return QModbusTcpConnectionObserver_shell::__shell()->javaMethod(typeid(QModbusTcpConnectionObserver), pos); }

// emitting (writeShellConstructor)
QModbusTcpConnectionObserver_shell::QModbusTcpConnectionObserver_shell()
    : QModbusTcpConnectionObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QModbusTcpConnectionObserver::QModbusTcpConnectionObserver_shell()", QModbusTcpConnectionObserver_shell::__shell())
    QModbusTcpConnectionObserver_shell::__shell()->constructed(typeid(QModbusTcpConnectionObserver));
}

// emitting (writeShellDestructor)
QModbusTcpConnectionObserver_shell::~QModbusTcpConnectionObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QModbusTcpConnectionObserver::~QModbusTcpConnectionObserver()", QModbusTcpConnectionObserver_shell::__shell())
    QModbusTcpConnectionObserver_shell::__shell()->destructed(typeid(QModbusTcpConnectionObserver));
}

void QModbusTcpConnectionObserver_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QModbusTcpConnectionObserver_shell*>(ptr)->QModbusTcpConnectionObserver_shell::__shell()->tryDeleteShell(typeid(QModbusTcpConnectionObserver));
}

// emitting Virtual overrides (virtualFunctions)
bool QModbusTcpConnectionObserver_shell::acceptNewConnection(QTcpSocket* newClient0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QModbusTcpConnectionObserver::", QModbusTcpConnectionObserver_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QModbusTcpConnectionObserver_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_newClient0 = QtJambiAPI::convertNativeToJavaObjectAsWrapper(__jni_env, reinterpret_cast<void*>(newClient0), Java::QtNetwork::QTcpSocket::getClass(__jni_env));
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_newClient0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QModbusTcpConnectionObserver_shell::__shell()->warnForMethod("QModbusTcpConnectionObserver::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QModbusTcpConnectionObserver::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QModbusTcpConnectionObserver_access::__qt_acceptNewConnection_QTcpSocket_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject newClient0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QTcpSocket* __qt_newClient0 = QtJambiAPI::convertJavaObjectToNative<QTcpSocket>(__jni_env, newClient0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket * newClient)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket * newClient).";
    } else {
        bool __qt_return_value = acceptNewConnection(__qt_newClient0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QModbusTcpConnectionObserver_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QModbusTcpConnectionObserver *__qt_this = new(__qtjambi_ptr) QModbusTcpConnectionObserver_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QModbusTcpConnectionObserver_shell
void __qt_destruct_QModbusTcpConnectionObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QModbusTcpConnectionObserver")
    reinterpret_cast<QModbusTcpConnectionObserver_shell*>(ptr)->~QModbusTcpConnectionObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QModbusTcpConnectionObserver::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QModbusTcpConnectionObserver_00024Impl_initialize_1native__Lio_qt_serialbus_QModbusTcpConnectionObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QModbusTcpConnectionObserver::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QModbusTcpConnectionObserver_0, sizeof(QModbusTcpConnectionObserver_shell), typeid(QModbusTcpConnectionObserver), true, &deleter_QModbusTcpConnectionObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QModbusTcpConnectionObserver_00024Impl_00024ConcreteWrapper_acceptNewConnection_1native_1QTcpSocket_1ptr__JLio_qt_network_QTcpSocket_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jobject newClient0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QModbusTcpConnectionObserver *__qt_this = QtJambiAPI::interfaceFromNativeId<QModbusTcpConnectionObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket*)", __qt_this)
        __java_return_value = static_cast<QModbusTcpConnectionObserver_access*>(__qt_this)->__qt_acceptNewConnection_QTcpSocket_ptr(__jni_env, __this_nativeId, newClient0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QModbusTcpConnectionObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QModbusTcpConnectionObserver>("QModbusTcpConnectionObserver", "io/qt/serialbus/QModbusTcpConnectionObserver");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "acceptNewConnection", "(Lio/qt/network/QTcpSocket;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QModbusTcpConnectionObserver, {
        ConstructorInfo(&__qt_construct_QModbusTcpConnectionObserver_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QModbusTcpConnectionObserver);
    registerSizeOfShell(typeId, sizeof(QModbusTcpConnectionObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QModbusTcpConnectionObserver* _object = dynamic_cast<QModbusTcpConnectionObserver*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QModbusTcpConnectionObserver *object = reinterpret_cast<QModbusTcpConnectionObserver *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QModbusTcpConnectionObserver *object = reinterpret_cast<const QModbusTcpConnectionObserver *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-macos-6.6.3.jar: sources/QtJambiSerialBus/QModbusTcpConnectionObserver_shell.cpp <==
#include "QModbusTcpConnectionObserver_shell.h"
#include <QtJambi/Cast>

void deleter_QModbusTcpConnectionObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QModbusTcpConnectionObserver")
    QModbusTcpConnectionObserver *_ptr = reinterpret_cast<QModbusTcpConnectionObserver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QModbusTcpConnectionObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QModbusTcpConnectionObserver_shell) ); }

jmethodID QModbusTcpConnectionObserver_shell::__shell_javaMethod(int pos) const { return QModbusTcpConnectionObserver_shell::__shell()->javaMethod(typeid(QModbusTcpConnectionObserver), pos); }

// emitting (writeShellConstructor)
QModbusTcpConnectionObserver_shell::QModbusTcpConnectionObserver_shell()
    : QModbusTcpConnectionObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QModbusTcpConnectionObserver::QModbusTcpConnectionObserver_shell()", QModbusTcpConnectionObserver_shell::__shell())
    QModbusTcpConnectionObserver_shell::__shell()->constructed(typeid(QModbusTcpConnectionObserver));
}

// emitting (writeShellDestructor)
QModbusTcpConnectionObserver_shell::~QModbusTcpConnectionObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QModbusTcpConnectionObserver::~QModbusTcpConnectionObserver()", QModbusTcpConnectionObserver_shell::__shell())
    QModbusTcpConnectionObserver_shell::__shell()->destructed(typeid(QModbusTcpConnectionObserver));
}

void QModbusTcpConnectionObserver_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QModbusTcpConnectionObserver_shell*>(ptr)->QModbusTcpConnectionObserver_shell::__shell()->tryDeleteShell(typeid(QModbusTcpConnectionObserver));
}

// emitting Virtual overrides (virtualFunctions)
bool QModbusTcpConnectionObserver_shell::acceptNewConnection(QTcpSocket* newClient0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QModbusTcpConnectionObserver::", QModbusTcpConnectionObserver_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QModbusTcpConnectionObserver_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_newClient0 = QtJambiAPI::convertNativeToJavaObjectAsWrapper(__jni_env, reinterpret_cast<void*>(newClient0), Java::QtNetwork::QTcpSocket::getClass(__jni_env));
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_newClient0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QModbusTcpConnectionObserver_shell::__shell()->warnForMethod("QModbusTcpConnectionObserver::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QModbusTcpConnectionObserver::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QModbusTcpConnectionObserver_access::__qt_acceptNewConnection_QTcpSocket_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject newClient0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QTcpSocket* __qt_newClient0 = QtJambiAPI::convertJavaObjectToNative<QTcpSocket>(__jni_env, newClient0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket * newClient)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket * newClient).";
    } else {
        bool __qt_return_value = acceptNewConnection(__qt_newClient0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QModbusTcpConnectionObserver()
void __qt_construct_QModbusTcpConnectionObserver(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QModbusTcpConnectionObserver()")
    Q_UNUSED(__java_arguments)
    QModbusTcpConnectionObserver *__qt_this = new(__qtjambi_ptr) QModbusTcpConnectionObserver_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QModbusTcpConnectionObserver::QModbusTcpConnectionObserver()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QModbusTcpConnectionObserver_00024Impl_initialize_1native__Lio_qt_serialbus_QModbusTcpConnectionObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QModbusTcpConnectionObserver::QModbusTcpConnectionObserver()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QModbusTcpConnectionObserver, sizeof(QModbusTcpConnectionObserver_shell), typeid(QModbusTcpConnectionObserver), true, &deleter_QModbusTcpConnectionObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QModbusTcpConnectionObserver_shell
void __qt_destruct_QModbusTcpConnectionObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QModbusTcpConnectionObserver")
    reinterpret_cast<QModbusTcpConnectionObserver_shell*>(ptr)->~QModbusTcpConnectionObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QModbusTcpConnectionObserver_00024Impl_00024ConcreteWrapper_acceptNewConnection_1native_1QTcpSocket_1ptr__JLio_qt_network_QTcpSocket_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jobject newClient0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QModbusTcpConnectionObserver *__qt_this = QtJambiAPI::interfaceFromNativeId<QModbusTcpConnectionObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket*)", __qt_this)
        __java_return_value = static_cast<QModbusTcpConnectionObserver_access*>(__qt_this)->__qt_acceptNewConnection_QTcpSocket_ptr(__jni_env, __this_nativeId, newClient0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QModbusTcpConnectionObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QModbusTcpConnectionObserver>("QModbusTcpConnectionObserver", "io/qt/serialbus/QModbusTcpConnectionObserver");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "acceptNewConnection", "(Lio/qt/network/QTcpSocket;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QModbusTcpConnectionObserver, {
        ConstructorInfo(&__qt_construct_QModbusTcpConnectionObserver, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QModbusTcpConnectionObserver);
    registerSizeOfShell(typeId, sizeof(QModbusTcpConnectionObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QModbusTcpConnectionObserver* _object = dynamic_cast<QModbusTcpConnectionObserver*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QModbusTcpConnectionObserver *object = reinterpret_cast<QModbusTcpConnectionObserver *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QModbusTcpConnectionObserver *object = reinterpret_cast<const QModbusTcpConnectionObserver *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
